#
# spec file for package python-hdf5storage
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-hdf5storage
Version:        0.1.19
Release:        3.2
Summary:        Utilities to read/write HDF5 files, including MATLAB v7.3 MAT files
License:        BSD-3-Clause
URL:            https://github.com/frejanordsiek/hdf5storage
Source:         https://files.pythonhosted.org/packages/source/h/hdf5storage/hdf5storage-%{version}.tar.gz
# PATCH-FIX-UPSTREAM nose-to-pytest.patch gh#frejanordsiek/hdf5storage#96 mcepl@suse.com, uses pytest instead of nose
Patch0:         nose-to-pytest.patch
# PATCH-FIX-UPSTREAM hdf5storage-pr134-numpy2.patch gh#frejanordsiek/hdf5storage#135 (backport to 0.1)
Patch1:         hdf5storage-pr134-numpy2.patch
BuildRequires:  %{python_module h5py >= 3.3}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest >= 6.0}
# I don't know how to do @pytest.mark.parametrize on class methods
BuildRequires:  %{python_module parameterized}
BuildRequires:  %{python_module scipy}
# /SECTION
Requires:       python-h5py >= 3.3
Requires:       python-numpy
Recommends:     python-scipy
BuildArch:      noarch
%python_subpackages

%description
This Python package provides high level utilities to read/write a
variety of Python types to/from HDF5 (Heirarchal Data Format) formatted
files. This package also provides support for MATLAB MAT v7.3 formatted
files, which are just HDF5 files with a different extension and some
extra meta-data.

%prep
%autosetup -p1 -n hdf5storage-%{version}
# fix end-of-line encoding
sed -i 's/\r$//' COPYING.txt

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license COPYING.txt
%{python_sitelib}/hdf5storage/
%{python_sitelib}/hdf5storage-%{version}.dist-info

%changelog
* Fri Aug 30 2024 Ben Greiner <code@bnavigator.de>
- Unpin numpy 2
  * Add hdf5storage-pr134-numpy2.patch
  * gh#frejanordsiek/hdf5storage#134 (backported)
- Make it noarch again
* Sun Jul  7 2024 Ben Greiner <code@bnavigator.de>
- Limit to numpy <2: Not compatible
* Wed Apr  5 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.1.19 Bugfix release:
  * Issue #122 and #124. Replaced use of deprecated ``numpy.asscalar``
    functions with the ``numpy.ndarray.item`` method.
  * Issue #123. Forced the use of English month and day of the week names
    in the HDF5 header for MATLAB compatibility.
  * Issue #125. Fixed accidental collection of
    ``pkg_resources.parse_version`` from setuptools as a Marshaller now
    that it is a class.
* Sat Jan 29 2022 Matej Cepl <mcepl@suse.com>
- Update 0.1.18 (performance improving release):
  - Pull Request #111 from Daniel Hrisca. Many repeated calls to
    the __getitem__ methods of objects were turned into single
    calls.
  - Further reducionts in __getitem__ calls in the spirit of PR
    [#111].
- Update to 0.1.17 (bugfix and deprecation workaround release):
  - Issue #109. Fixed the fix Issue #102 for 32-bit platforms
    (previous fix was segfaulting).
  - Moved to using pkg_resources.parse_version from setuptools
    with distutils.version classes as a fallback instead of just
    the later to prepare for the removal of distutils (PEP 632)
    and prevent warnings on Python versions where it is marked as
    deprecated.
  - Issue #110. Changed all uses of the tostring method on numpy
    types to using tobytes if available, with tostring as the
    fallback for old versions of numpy where it is not.
- Add nose-to-pytest.patch which allows use of pytest instead of
  nose (not based on the upstream solution).
* Mon Mar  8 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.1.16
  * Issue #81 and #82. h5py.File will require the mode to be
    passed explicitly in the future. All calls without passing it
    were fixed to pass it.
  * Issue #102. Added support for h5py 3.0 and 3.1.
  * Issue #73. Fixed bug where a missing variable in loadmat would
    cause the function to think that the file is a pre v7.3 format
    MAT file fall back to scipy.io.loadmat which won't work since
    the file is a v7.3 format MAT file.
  * Fixed formatting issues in the docstrings and the
    documentation that prevented the documentation from building.
- Release 0.1.15
  * Issue #68. Fixed bug where str and numpy.unicode_ strings (but
    not ndarrays of them) were saved in uint32 format regardless
    of the value of Options.convert_numpy_bytes_to_utf16.
  * Issue #70. Updated setup.py and requirements.txt to specify
    the maximum versions of numpy and h5py that can be used for
    specific python versions (avoid version with dropped support).
  * Issue #71. Fixed bug where the 'python_fields' attribute
    wouldn't always be written when doing python metadata for data
    written in a struct-like fashion. The bug caused the field
    order to not be preserved when writing and reading.
  * Fixed an assertion in the tests to handle field re-ordering
    when no metadata is used for structured dtypes that only
    worked on older versions of numpy.
  * Issue #72. Fixed bug where python collections filled with
    ndarrays that all have the same shape were converted to
    multi-dimensional object ndarrays instead of a 1D object
    ndarray of the elements.
- Skip python2 (dropped upstream) and python36 (NumPy 1.20, NEP 29)
- Don't build for 32-bit gh#frejanordsiek/hdf5storage#109
* Thu May 24 2018 toddrme2178@gmail.com
- Spec file cleanups
* Sun Jun 11 2017 toddrme2178@gmail.com
- Implement single-spec version
- Fix source URL
- Update to version 0.1.14.
  + Bugfix release that also added a couple features.
  * Issue #45. Fixed syntax errors in unicode strings for Python 3.0 to 3.2.
  * Issues #44 and #47. Fixed bugs in testing of conversion and storage of string types.
  * Issue #46. Fixed raising of RuntimeWarnings in tests due to signalling NaNs.
  * Added requirements files for building documentation and running tests.
  * Made it so that Matlab compatability tests are skipped if Matlab is not found, instead of raising errors.
- Update to version 0.1.13.
  + Bugfix release fixing the following bug.
  * Issue #36. Fixed bugs in writing int and long to HDF5 and their tests on 32 bit systems.
- Update to version 0.1.12.
  + Bugfix release fixing the following bugs. In addition, copyright years were also updated and notices put in the Matlab files used for testing.
  * Issue #32. Fixed transposing before reshaping np.ndarray when reading from HDF5 files where python metadata was stored but not Matlab metadata.
  * Issue #33. Fixed the loss of the number of characters when reading empty numpy string arrays.
  * Issue #34. Fixed a conversion error when np.chararray are written with Matlab metadata.
- Update to version 0.1.11.
  + Bugfix release fixing the following.
  * Issue #30. Fixed loadmat not opening files in read mode.
- Update to version 0.1.10.
  + Minor feature/performance fix release doing the following.
  * Issue #29. Added writes and reads functions to write and read more than one piece of data at a time and made savemat and loadmat use them to increase performance. Previously, the HDF5 file was being opened and closed for each piece of data, which impacted performance, especially for large files.
- Update to version 0.1.9.
  + Bugfix and minor feature release doing the following.
  * Issue #23. Fixed bug where a structured np.ndarray with a field name of 'O' could never be written as an HDF5 COMPOUND Dataset (falsely thought a field’s dtype was object).
  * Issue #6. Added optional data compression and the storage of data checksums. Controlled by several new options.
- Update to version 0.1.8.
  + Bugfix release fixing the following two bugs.
  * Issue #21. Fixed bug where the 'MATLAB_class' Attribute is not set when writing dict types when writing MATLAB metadata.
  * Issue #22. Fixed bug where null characters ('\x00') and forward slashes ('/') were allowed in dict keys and the field names of structured np.ndarray (except that forward slashes are allowed when the structured_numpy_ndarray_as_struct is not set as is the case when the matlab_compatible option is set). These cause problems for the h5py package and the HDF5 library. NotImplementedError is now thrown in these cases.
- Update to version 0.1.7.
  + Bugfix release with an added compatibility option and some added test code. Did the following.
  * Fixed an issue reading variables larger than 2 GB in MATLAB MAT v7.3 files when no explicit variable names to read are given to hdf5storage.loadmat. Fix also reduces memory consumption and processing time a little bit by removing an unneeded memory copy.
  * Options now will accept any additional keyword arguments it doesn’t support, ignoring them, to be API compatible with future package versions with added options.
  * Added tests for reading data that has been compressed or had other HDF5 filters applied.
- Update to version 0.1.6.
  + Bugfix release fixing a bug with determining the maximum size of a Python 2.x int on a 32-bit system.
- Update to version 0.1.5.
  + Bugfix release fixing the following bug.
  * Fixed bug where an int could be stored that is too big to fit into an int when read back in Python 2.x. When it is too big, it is converted to a long.
  * Fixed a bug where an int or long that is too big to big to fit into an np.int64 raised the wrong exception.
  * Fixed bug where fields names for structured np.ndarray with non-ASCII characters (assumed to be UTF-8 encoded in Python 2.x) can’t be read or written properly.
  * Fixed bug where np.bytes_ with non-ASCII characters can were converted incorrectly to UTF-16 when that option is set (set implicitly when doing MATLAB compatibility). Now, it throws a NotImplementedError.
- Update to version 0.1.4.
  + Bugfix release fixing the following bugs. Thanks goes to mrdomino for writing the bug fixes.
  * Fixed bug where dtype is used as a keyword parameter of np.ndarray.astype when it is a positional argument.
  * Fixed error caused by h5py.__version__ being absent on Ubuntu 12.04.
- Update to version 0.1.3.
  + Bugfix release fixing the following bug.
  * Fixed broken ability to correctly read and write empty structured np.ndarray (has fields).
- Update to version 0.1.2.
  + Bugfix release fixing the following bugs.
  * Removed mistaken support for np.float16 for h5py versions before 2.2 since that was when support for it was introduced.
  * Structured np.ndarray where one or more fields is of the 'object' dtype can now be written without an error when the structured_numpy_ndarray_as_struct option is not set. They are written as an HDF5 Group, as if the option was set.
  * Support for the 'MATLAB_fields' Attribute for data types that are structures in MATLAB has been added for when the version of the h5py package being used is 2.3 or greater. Support is still missing for earlier versions (this package requires a minimum version of 2.1).
  * The check for non-unicode string keys (str in Python 3 and unicode in Python 2) in the type dict is done right before any changes are made to the HDF5 file instead of in the middle so that no changes are applied if an invalid key is present.
  * HDF5 userblock set with the proper metadata for MATLAB support right at the beginning of when data is being written to an HDF5 file instead of at the end, meaning the writing can crash and the file will still be a valid MATLAB file.
* Fri May 30 2014 toddrme2178@gmail.com
- initial version
